antares.apps.user.migrations package — Antares 0.0.2 documentation

# antares.apps.user.migrations package

## Submodules

## antares.apps.user.migrations.0001_initial module

## antares.apps.user.migrations.0002_auto_20190629_1936 module

class `antares.apps.user.migrations.0002_auto_20190629_1936.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('user', '0001_initial')]
  `operations` = [<AlterField model_name='application', name='level', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='application', name='lft', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='application', name='rght', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='orgunit', name='level', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='orgunit', name='lft', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='orgunit', name='rght', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='role', name='level', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='role', name='lft', field=<django.db.models.fields.PositiveIntegerField>>, <AlterField model_name='role', name='rght', field=<django.db.models.fields.PositiveIntegerField>>]

## Module contents